<?php
namespace Ep\Woo\Plugin\Category;

use Ak\Wp\Plugin\PluginInterface;

/**
 * Uklanja kategoriju proizvoda Uncategorized ili Nekategorizirane.
 *
 * @package Ep\Woo\Plugin\Category
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-woocommerce
 */
class Uncategorized implements PluginInterface
{
    /** @var array */
    private $slugs = [
        'nekategorizirane',
        'uncategorized',
    ];

    /**
     * Dodaje akcije i filtere u WordPress.
     *
     * @return void
     */
    public function attach(): void
    {
        add_action('init', [$this, 'init']);
    }

    /**
     * Briše kategorije ako postoje.
     */
    public function init():void
    {
        foreach ($this->slugs as $slug) {
            if ($term = get_term_by('slug', $slug, 'product_cat')) {
                // WooCoommerce dodaje u array bez da ga deklarira prije
                // pod određenim okolnostima ne doda ništa u taj array, pa ga
                // time ni ne deklarira.
                //
                // Emitirana je E_NOTICE greška 'Undefined variable: clear_ids'
                $oldLevel = error_reporting(error_reporting() & ~E_NOTICE & ~E_WARNING);
                wp_delete_term($term->term_id, 'product_cat');
                error_reporting($oldLevel);
            }
        }
    }
}