<?php
namespace Ep\Woo\Plugin\Payment;

use Ep\Currency\Converter;
use Ak\Wp\Plugin\PluginInterface;

/**
 * Class Braintree
 *
 * @package Ep\Woo\Plugin\Payment
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-woocommerce
 */
class Braintree implements PluginInterface
{
    /** @var Converter */
    private $converter;

    /**
     * Braintree constructor.
     *
     * @param Converter $converter
     */
    public function __construct(Converter $converter)
    {
        $this->converter = $converter;
    }

    /**
     * Dodaje akcije i filtere u WordPress.
     *
     * @return void
     */
    public function attach(): void
    {
        add_filter('braintree_woocommerce_braintree_payment_gateway_order_attributes', [$this, 'wc_braintree_order_attributes']);
        add_filter('braintree_woocommerce_process_order_success', [$this, 'wc_process_order_success']);
    }

    public function wc_braintree_order_attributes(array $attribs)
    {
        if (get_woocommerce_currency() !== 'EUR') {
            $attribs['amount'] = (string) round($this->converter->convert(get_woocommerce_currency(), 'EUR', floatval($attribs['amount'])), 2);
            $attribs['taxAmount'] = (string) round($this->converter->convert(get_woocommerce_currency(), 'EUR', floatval($attribs['taxAmount'])), 2);
            global $bfwc_order_total;
            $bfwc_order_total = $attribs['amount'];
        }

        $attribs['taxAmount'] = (string) $attribs['taxAmount'];

        return $attribs;
    }

    public function wc_process_order_success($data)
    {
        $order = wc_get_order($data['order_id']);
        global $bfwc_order_total;
        $bfwc_order_total = $order->get_total();

        return $data;
    }
}