<?php
namespace Ep\Woo\Plugin\Payment;

use Ep\Currency\Converter;
use Ak\Wp\Plugin\PluginInterface;

/**
 * Class Paypal
 *
 * @package Ep\Woo\Plugin
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-woocommerce
 */
class Paypal implements PluginInterface
{
    /** @var Converter */
    private $converter;

    /**
     * Paypal constructor.
     *
     * @param Converter $converter
     */
    public function __construct(Converter $converter)
    {
        $this->converter = $converter;
    }

    /**
     * Dodaje akcije i filtere u WordPress.
     */
    public function attach(): void
    {
        add_action('woocommerce_thankyou_paypal', [$this, 'wc_thankyou_paypal']);
        add_filter('woocommerce_paypal_args', [$this, 'wc_paypal_args']);
        add_filter('woocommerce_paypal_supported_currencies', [$this, 'wc_paypal_supported_currencies']);
    }

    /**
     * @param array $currencies
     *
     * @return array
     */
    public function wc_paypal_supported_currencies(array $currencies): array
    {
        $currencies[] = get_woocommerce_currency();
        return $currencies;
    }

    /**
     * @param array $args
     *
     * @return array
     */
    public function wc_paypal_args(array $args): array
    {
        if (($currency = $args['currency_code']) !== 'EUR') {
            $args['currency_code'] = 'EUR';
            $i = 1;

            while (isset($args['amount_' . $i])) {
                $args['amount_' . $i] = $this->converter->convert($currency, 'EUR', $args['amount_' . $i]);
                $i++;
            }

            if (isset($args['discount_amount_cart']) && $args['discount_amount_cart'] > 0) {
                $args['discount_amount_cart'] = $this->converter->convert($currency, 'EUR', $args['discount_amount_cart']);
            }

            if (isset($args['tax_cart']) && $args['tax_cart'] > 0) {
                $args['tax_cart'] = $this->converter->convert($currency, 'EUR', $args['tax_cart']);
            }

            if (isset($args['shipping_1']) && $args['shipping_1'] > 0) {
                $args['shipping_1'] = $this->converter->convert($currency, 'EUR', $args['shipping_1']);
            }
        }

        return $args;
    }

    /**
     * S Paypala dolazi iznos u eurima. Validacija pukne kada uspoređuje
     * sa iznosom u narudžbi. Ovo osigura da validacija uvijek prolazi.
     *
     * @param int $order_id
     */
    public function wc_thankyou_paypal(int $order_id)
    {
        $order = wc_get_order($order_id);
        $_REQUEST['amt'] = $order->get_total();
    }
}