<?php
namespace Ep\Woo\Plugin;

use Ak\Wp\Plugin\PluginInterface;

/**
 * Class RestApi
 *
 * @package Ep\Woo\Plugin
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-woocommerce
 */
class RestApi implements PluginInterface
{
    /**
     * Dodaje akcije i filtere u WordPress.
     */
    public function attach(): void
    {
        add_filter('rest_pre_dispatch', [$this, 'rest_pre_dispatch'], 10, 3);
    }

    /**
     * Mijenja request prije nego što udari REST api.
     *
     * @param $null
     * @param $server
     * @param \WP_REST_Request $request
     *
     * @return mixed
     */
    public function rest_pre_dispatch($null, /** @noinspection PhpUnusedParameterInspection */ $server, \WP_REST_Request $request)
    {
        ini_set('display_errors', 0);

        if (preg_match('#^/wc/v2/products/(categories|brands)#', $request->get_route())) {
            $body = json_decode($request->get_body(), true);

            if (is_array($body)) {
                if (array_key_exists('slug', $body)) {
                    unset($body['slug']);
                    $request->set_body(json_encode($body));
                }
            }
        } else if (preg_match('#/wc/v2/products/attributes/\d+$#', $request->get_route()) && 'PUT' === $_SERVER['REQUEST_METHOD']) {
            $body = json_decode($request->get_body(), true);
            if (!isset($body['slug']) && isset($body['name'])) {
                $body['slug'] = wc_sanitize_taxonomy_name(stripslashes($body['name']));
                $request->set_body(json_encode($body));
            }
        }

        return $null;
    }
}